#!/usr/bin/env python
# coding=UTF-8
#
# Copyright (C) 2010 Stefanos Harhalakis
#
# This file is part of wifieye.
#
# wifieye is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# wifieye is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with wifieye.  If not, see <http://www.gnu.org/licenses/>.
#
# $Id: win.py 2251 2010-02-13 14:45:57Z v13 $

from PyQt4 import QtGui, QtCore
from PyQt4.QtCore import SIGNAL, Qt

import sys

import graphchannels, graphtime, wifi, data
#import portrait

win=None

class Ui_Channels:
    def setupUi(self, w):
	self.centralwidget=QtGui.QWidget(w)
	self.centralwidget.setObjectName("centralwidget")

	self.l0=QtGui.QVBoxLayout(self.centralwidget)

	self.graph=graphchannels.GraphChannels()
	self.graph.setObjectName("graph")
	self.l0.addWidget(self.graph)

	self.l1=QtGui.QHBoxLayout()
	self.buttonTimeview=QtGui.QPushButton(self.centralwidget)
	self.l1.addWidget(self.buttonTimeview)
	self.buttonRefresh=QtGui.QPushButton(self.centralwidget)
	self.l1.addWidget(self.buttonRefresh)
	self.buttonAutoRefresh=QtGui.QPushButton(self.centralwidget)
	self.buttonAutoRefresh.setCheckable(True)
	self.l1.addWidget(self.buttonAutoRefresh)
	spacer=QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding,
	    QtGui.QSizePolicy.Minimum)
	self.l1.addItem(spacer)
	self.l0.addLayout(self.l1)

	w.setCentralWidget(self.centralwidget)

    def retranslateUi(self):
	self.buttonRefresh.setText("Refresh")
	self.buttonAutoRefresh.setText("Auto Refresh")
	self.buttonTimeview.setText("Time Graph")

class Ui_Time:
    def setupUi(self, w):
	self.centralwidget=QtGui.QWidget(w)
	self.centralwidget.setObjectName("centralwidget")

	self.l0=QtGui.QVBoxLayout(self.centralwidget)

	self.graph=graphtime.GraphTime()
	self.graph.setObjectName("graph")
	self.l0.addWidget(self.graph)

	self.l1=QtGui.QHBoxLayout()
	self.buttonChannelview=QtGui.QPushButton(self.centralwidget)
	self.l1.addWidget(self.buttonChannelview)
	self.buttonClear=QtGui.QPushButton(self.centralwidget)
	self.l1.addWidget(self.buttonClear)
	self.buttonPause=QtGui.QPushButton(self.centralwidget)
	self.buttonPause.setCheckable(True)
	self.l1.addWidget(self.buttonPause)

	spacer=QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding,
	    QtGui.QSizePolicy.Minimum)
	self.l1.addItem(spacer)
	self.l0.addLayout(self.l1)

	w.setCentralWidget(self.centralwidget)

    def retranslateUi(self):
	self.buttonChannelview.setText("Channels")
	self.buttonClear.setText("Clear")
	self.buttonPause.setText("Pause")


class MainWin(QtGui.QMainWindow):
    def __init__(self, *args, **kwargs):
	QtGui.QMainWindow.__init__(self, *args, **kwargs)

	self.ui=None
	self.what=None

	self.chtimer=None
	self.tmtimer=None

	self.setupUiChannels()

    def setupUiChannels(self):
	self.what='channels'

	self.ui=Ui_Channels()
	self.ui.setupUi(self)
	self.retranslateUi()

	self.connect(self.ui.buttonRefresh, SIGNAL('clicked()'),
		self.slotChRefresh)
	self.connect(self.ui.buttonAutoRefresh, SIGNAL('toggled(bool)'),
		self.slotChAutoRefresh)
	self.connect(self.ui.buttonTimeview, SIGNAL('clicked()'),
		self.slotChTimeview)

	self.slotChRefresh()

    def setupUiTime(self):
	self.what='time'

	self.ui=Ui_Time()
	self.ui.setupUi(self)
	self.retranslateUi()

	self.connect(self.ui.buttonChannelview, SIGNAL('clicked()'),
		self.slotTmChannelview)
	self.connect(self.ui.buttonClear, SIGNAL('clicked()'),
		self.slotTmClear)
	self.connect(self.ui.buttonPause, SIGNAL('toggled(bool)'),
		self.slotTmPause)

	#self.slotTmTimerGetData()
	self.startTmTimer()

    def retranslateUi(self):
	self.setWindowTitle("Wifi Eye")
	self.ui.retranslateUi()

    def setupUi(self):
	self.graph=None
	self.setupUiChannels()
	#self.setupUiTime()

    def startChTimer(self):
	self.chtimer=QtCore.QTimer(self)
	self.connect(self.chtimer, SIGNAL('timeout()'),
	    self.slotChTimerAutorefresh)
	self.chtimer.start(1300)

    def stopChTimer(self):
	if self.chtimer==None:
	    return
	self.chtimer.stop()
	self.chtimer=None

    def startTmTimer(self):
	self.tmtimer=QtCore.QTimer(self)
	self.connect(self.tmtimer, SIGNAL('timeout()'),
	    self.slotTmTimerGetData)
	self.tmtimer.start(1300)
	
    def stopTmTimer(self):
	if self.tmtimer==None:
	    return
	self.tmtimer.stop()
	self.tmtimer=None

    # -------------------------------
    # Slots:
    # slotCh* are for Channel view
    # slotTm* are for Time view

    # -------------------------------
    def slotChRefresh(self):
	if self.ui.buttonAutoRefresh.isChecked():
	    wifi.scanAsync(self.slotChScanAsync)
	else:
	    # Disable the button but re-enable it if scanSync() failed
	    # This happens when there is another scan active
	    # (e.g. when changing from time-view to channel-view)
	    self.ui.buttonRefresh.setEnabled(False)
	    if not wifi.scanAsync(self.slotChScanAsync):
		self.ui.buttonRefresh.setEnabled(True)

    def slotChAutoRefresh(self, checked):
	if checked:
	    self.ui.buttonRefresh.setEnabled(False)
	    if self.chtimer==None:
		self.startChTimer()
	else:
	    self.ui.buttonRefresh.setEnabled(True)
	    self.stopChTimer()

    def slotChTimeview(self):
	self.stopChTimer()
	self.setupUiTime()

    def slotChScanAsync(self, dt):
	if self.what!='channels':
	    return
	if not self.ui.buttonAutoRefresh.isChecked():
	    self.ui.buttonRefresh.setEnabled(True)
	data.setone(dt)
	self.repaint()

    def slotChTimerAutorefresh(self):
	if self.what!='channels':
	    return
	self.slotChRefresh()

    # -------------------------------
    def slotTmChannelview(self):
	self.stopTmTimer()
	self.setupUiChannels()
	#self.tmtimer=None

    def slotTmTimerGetData(self):
	if self.what!='time':
	    return
	dt=wifi.scanAsync(self.slotTmScanAsync)

    def slotTmClear(self):
	data.clear()
	self.repaint()

    def slotTmScanAsync(self, dt):
	if self.what!='time':
	    return
	data.add(dt)
	self.repaint()
	#QtCore.QTimer.singleShot(1000, self.slotTmTimerGetData)

    def slotTmPause(self, checked):
	if checked:
	    self.stopTmTimer()
	else:
	    self.startTmTimer()

def init():
    global app, win, por
    app=QtGui.QApplication(sys.argv)
    #app.setAttribute(Qt.WA_Maemo5ForceLandscapeOrientation, True);
#    win0=QtGui.QMainWindow()
    win=MainWin()
    #por=portrait.FremantleRotation("wifieye", win, '1.0')

    win.setupUi()

def doit(dt):
    global app, win

    win.show()
    ret=app.exec_()
    wifi.finish()

    sys.exit(ret)

# vim: set ts=8 sts=4 sw=4 noet formatoptions=r ai nocindent:

